/* 
 * File:   loop.h
 * Author: ak119685
 *
 * Created on 23 Апрель 2010 г., 0:16
 */

#ifndef _LOOP_H
#define	_LOOP_H

#ifdef	__cplusplus
extern "C" {
#endif

    int loop(int master_fd);

#ifdef	__cplusplus
}
#endif

#endif	/* _LOOP_H */

